"""Static time definitions."""

import numpy as np
import pandas as pd

start_hydroyear = 4
season_start = np.array([4, 7, 10, 1])
season_names = np.array(['Spring', 'Summer', 'Autumn', 'Winter'])
season_month_range = np.array(['Mar-May', 'Jun-Aug', 'Sep-Nov', 'Dec-Feb'])


def get_index_hydroyear():
    '''Return an index with the end of each hydrological year.'''
    range_years = np.arange(2010, 2024)
    date_range = [pd.Timestamp(year=year, month=start_hydroyear, day=1) - pd.Timedelta(1, unit='d') for year in range_years]
    date_range = pd.DatetimeIndex(date_range)
    return date_range


def get_period_hydroyear(year):
    '''Return the beginning and end of a hydrological year.'''
    begin = pd.Timestamp(year=year, month=start_hydroyear, day=1)
    end = pd.Timestamp(year=year+1, month=start_hydroyear, day=1) - pd.Timedelta(1, unit='s')
    return [begin, end]


def get_hydroyear_from_index(index):
    '''Return an index containing the hydrological of each element of the inserted index.'''
    index_hy = index.year.values
    index_hy[index.month < start_hydroyear] = index_hy[index.month < start_hydroyear] - 1
    return index_hy
